# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Source Filters for Perl
Name:		perl-Filter
Epoch:		1
Version:	1.49
Release:	3.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		https://github.com/rurban/Filter
Source0:	http://search.cpan.org/CPAN/authors/id/R/RU/RURBAN/Filter-%{version}.tar.gz
Patch0:		Filter-1.49-done-testing.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(Perl::MinimumVersion) >= 1.20
BuildRequires:	perl(Test::CPAN::Meta) >= 0.12
BuildRequires:	perl(Test::MinimumVersion) >= 0.008
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.0
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Avoid Test::Kwalitee as it tries to verify the module's signature, which will fail
# if we have to patch Makefile.PL, tests etc. for old distribution support
BuildConflicts:	perl(Test::Kwalitee)

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
This package provides source-level filters for Perl modules. Source
filters alter the program text of a module before Perl sees it, much
as a C preprocessor alters the source text of a C program before the
compiler sees it.

%prep
%setup -q -n Filter-%{version}

# Upstream fix to omit empty Filter::decrypt from POD coverage test
%patch0

# Fix script interpreter
sed -i -e 's|^#!/usr/local/bin/perl|#!/usr/bin/perl|' examples/filtdef

# Avoid doc-file dependencies
chmod -c -x examples/filt{def,uu}
%global reqfilt /bin/sh -c "%{__perl_requires} | grep -Evx 'perl[(](Compress::Zlib|IO::File)[)]'"
%define __perl_requires %{reqfilt}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

# Build process creates junk
find . -type f -name '*.bak' -exec rm -vf {} ';'

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
%{_fixperms} %{buildroot}

%check
make test IS_MAINTAINER=1

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes README examples/
%{perl_vendorarch}/Filter/
%{perl_vendorarch}/auto/Filter/
%{_mandir}/man3/Filter::cpp.3pm*
%{_mandir}/man3/Filter::decrypt.3pm*
%{_mandir}/man3/Filter::exec.3pm*
%{_mandir}/man3/Filter::sh.3pm*
%{_mandir}/man3/Filter::tee.3pm*
%{_mandir}/man3/Filter::Util::Call.3pm*
%{_mandir}/man3/Filter::Util::Exec.3pm*
%{_mandir}/man3/Filter::Util::perlfilter.3pm*

%changelog
* Thu Jul 25 2013 Paul Howarth <paul@city-fan.org> 1:1.49-3
- Bump epoch as per Fedora package
- Avoid Test::Kwalitee as it tries to verify the module's signature, which will fail
  if we have to patch Makefile.PL, tests etc. for old distribution support
- Add upstream fix to omit empty Filter::decrypt from POD coverage test

* Wed Apr  3 2013 Paul Howarth <paul@city-fan.org> 1.49-1
- Update to 1.49:
  - Better fix for test failures with non-english locale (CPAN RT#41285)
  - Add t/z_*.t meta tests, move Try to t/FilterTry, add POD to
    Filter::Util::Call, Filter::Util::Exec and generated FilterTry
- BR: perl(File::Copy), perl(Perl::MinimumVersion) >= 1.20,
  perl(Test::CPAN::Meta) >= 0.12, perl(Test::Kwalitee),
  perl(Test::MinimumVersion) >= 0.008 and perl(Test::Pod::Coverage) >= 1.04 for
  the newly-added maintainer tests and explicitly run them
- Specify version requirement for perl(Test::Pod)
- Add patch to remove the need for Test::More::done_testing (CPAN RT#84405)

* Mon Apr  1 2013 Paul Howarth <paul@city-fan.org> 1.48-1
- Update to 1.48:
  - Added META records, such as repository, recommends to Makefile.PL

* Mon Apr  1 2013 Paul Howarth <paul@city-fan.org> 1.47-1
- Update to 1.47:
  - Fix test failures with non-English locale (CPAN RT#41285)

* Fri Mar 29 2013 Paul Howarth <paul@city-fan.org> 1.46-1
- Update to 1.46:
  - Fix PIPE_PID/waitpid broken in exec pipe_read since 5.17.6 (CPAN RT#84292)
  - Fix Bad NAME in Makefile.PL (CPAN RT#84210)
  - Fix cpansign MANIFEST failure (CPAN RT#82687)
  - Work on test failures with non-English locale (CPAN RT#41285)
  - Skip patching the src for newWarnings style; these are the default
  - Fix examples/method/Decompress.pm syntax error (CPAN RT#53132) and add
    usage docs

* Tue Jun 19 2012 Paul Howarth <paul@city-fan.org> 1.45-1
- Update to 1.45:
  - Sync perlfilter.pod with core improvements

* Mon Jun 18 2012 Paul Howarth <paul@city-fan.org> 1.44-1
- Update to 1.44:
  - Sync t/call.t with core fixes in 2adbc9b6
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Feb 22 2012 Paul Howarth <paul@city-fan.org> 1.43-1
- Update to 1.43:
  - Fix more windows tests:
    http://www.cpantesters.org/cpan/report/9e790a72-6bf5-1014-9f3b-641f296be760

* Tue Feb 21 2012 Paul Howarth <paul@city-fan.org> 1.42-1
- Update to 1.42:
  - Improve t/tee.t test 5 on Windows, which allows read access for all
    Administrator group members

* Sat Feb 18 2012 Paul Howarth <paul@city-fan.org> 1.41-1
- Update to 1.41:
  - Fix tee and all tests to work with Perl 5.14 and higher
  - PVIO has no IV field anymore, so abuse the empty IoOFP, which is only used
    for printing, not reading (fixes CPAN RT#56875 and more)
  - Tested for 5.6.2, 5.8.4, 5.8.5, 5.8.8, 5.8.9, 5.10.1, 5.12.4, 5.14.2,
    5.15.7
  - Hide example packages from the pause indexer
- This release by RURBAN -> update source URL
- Add buildreqs for Perl core modules that might be dual-lived

* Tue Oct 18 2011 Paul Howarth <paul@city-fan.org> 1.39-2
- Fix dist tag for CentOS 6 and Scientific Linux

* Sun May  1 2011 Paul Howarth <paul@city-fan.org> 1.39-1
- Update to 1.39:
  - Fix decrypt to work with Perl 5.14 (CPAN RT#67656)

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> 1.38-1
- Update to 1.38:
  - Bumped all versions to match the distribution version number, as having
    module versions different from distribution version results in dependency
    confusion (CPAN RT#67655)
  - Fix decrypt to work with Perl 5.14 (CPAN RT#67656)
  - Update the Filter-Simple URL (CPAN RT#49778)
- Fix doc-file dependencies
- Nobody else likes macros for commands

* Wed Sep 16 2009 Paul Howarth <paul@city-fan.org> 1.37-1
- Initial RPM package
